# Authors

Meshroom was made possible by the contributions of the following people:

## Maintainers

- **David Bizeul** (david.bizeul@sekoia.io): Project Lead
- **Jerome Fellus** (jerome.fellus@sekoia.io): Lead Developer